Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/color_picker_simpletest.py
    :caption: examples/color_picker_simpletest.py
    :linenos:
    :lines: 8-

Wheel Maker Example
-------------------

Shows how to make color wheel bitmaps

.. literalinclude:: ../examples/color_picker_wheel_maker_simpletest.py
    :caption: examples/color_picker_wheel_maker_simpletest.py
    :linenos:
    :lines: 8-
